@@ -1,13 +1,11 @@
 package Dancer::RPCPlugin::DispatchMethodList;
 use warnings;
 use strict;
+use Params::Validate ':all';
 
 use Exporter 'import';
 our @EXPORT = ('list_methods');
 
-use Types::Standard qw/ StrMatch ArrayRef /;
-use Params::ValidationCompiler 'validation_for';
-
 =head1 NAME
 
 Dancer::RPCPlugin::DispatchMethodList - Class for maintaining a global methodlist.
@@ -18,13 +16,13 @@ Dancer::RPCPlugin::DispatchMethodList - Class for maintaining a global methodlis
     my $methods = Dancer::RPCPlugin::DispatchMethodList->new();
 
     $methods->set_partial(
-        protocol => <jsonrpc|restrpc|xmlrpc>,
+        protocol => <jsonrpc|xmlrpc>,
         endpoint => </configured>,
         methods  => [ @method_names ],
     );
 
     # ....
-    my $method_list = $methods->list_methods(protocol => <any|jsonrpc|restrpc|xmlrpc>);
+    my $methods = list_methods(<any|jsonrpc|xmlrpc>);
 
 =head1 DESCRIPTION
 
@@ -58,9 +56,9 @@ Named, list:
 
 =over
 
-=item protocol => <jsonrpc|restrpc|xmlrpc> (required)
+=item protocol => <jsonrpc|xmlrpc>
 
-=item endpoint => $endpoint                (required)
+=item endpoint => $endpoint
 
 =item methods => \@method_list
 
@@ -74,28 +72,29 @@ Named, list:
 
 sub set_partial {
     my $self = shift;
-    my %args = validation_for(
-        params => {
-            protocol => {type => StrMatch[ qr/^(?:json|xml|rest)rpc$/ ], optional => 0},
-            endpoint => {type => StrMatch[ qr/^.*$/] , optional => 0},
-            methods  => {type => ArrayRef},
+    my $args = validate_with(
+        params => \@_,
+        spec   => {
+            protocol => {regex => qr/^(?:json|xml)rpc$/, optional => 0},
+            endpoint => {regex => qr/^.*$/, optional => 0},
+            methods  => {type => ARRAYREF},
         },
-    )->(@_);
-    $self->{protocols}{$args{protocol}}{$args{endpoint}} = $args{methods};
+    );
+    $self->{protocols}{$args->{protocol}}{$args->{endpoint}} = $args->{methods};
     return $self;
 }
 
 =head2 list_methods(@parameters)
 
-Method that returns information about the dispatch-table.
+This is not a method, but an exported function.
 
 =head3 Parameters
 
-Positional, list
+Positional, list:
 
 =over
 
-=item 1. $protocol => undef || <any|jsonrpc|restrpc|xmlrpc>  (optional)
+=item $protocol => undef || <any|jsonrpc|xmlrpc>
 
 =back
 
@@ -124,21 +123,15 @@ In case of specified C<$protocol>:
 =cut
 
 sub list_methods {
-    my $self = shift;
-    my ($protocol) = validation_for(
-        params => [
-            {
-                type     => StrMatch [qr/^(?:any|(?:json|rest|xml)rpc)$/],
-                default  => 'any',
-            },
-        ],
-    )->(@_);
-
+    my ($protocol) = validate_pos(
+        @_,
+        {default => 'any', regex => qr/^any|jsonrpc|xmlrpc$/, optional => 1}
+    );
     if ($protocol eq 'any') {
-        return $self->{protocols};
+        return $singleton->{protocols};
     }
     else {
-        return $self->{protocols}{$protocol};
+        return $singleton->{protocols}{$protocol};
     }
 }
 
