@@ -2,7 +2,6 @@ package TestProject;
 use Dancer ':syntax';
 use Dancer::Plugin::RPC::JSONRPC;
 use Dancer::Plugin::RPC::XMLRPC;
-use Dancer::Plugin::RPC::RESTRPC;
 
 # Register calls directly via POD
 xmlrpc '/system' => {
@@ -29,14 +28,6 @@ jsonrpc '/jsonrpc/api' => {
 # Register calls via YAML-config
 jsonrpc '/jsonrpc/admin' => { publish => 'config' };
 
-
-restrpc '/rest/system' => {
-    publish   => 'pod',
-    arguments => ['TestProject::SystemCalls'],
-};
-
-restrpc '/rest/api' => { publish => 'config' };
-
 true;
 
 __END__
@@ -53,8 +44,3 @@ jsonrpc:
     /jsonrpc/admin ping
     /jsonrpc/admin version
     /jsonrpc/admin uppercase (argument)
-
-restrpc:
-    /rest/system/ping
-    /rest/system/version
-    /rest/api/uppercase
